/**
 * @file   delegation.h
 * @brief  Utility routines related to proxy and delegation handling.
 * @author Alejandro Álvarez Ayllón <aalvarez.cern.ch>
 * @note   Most of these functions are based on Gridsite.
 */
#ifndef DELEGATION_H
#define DELEGATION_H

#include <httpd.h>

/** @brief  Return a pointer to a malloc'd string holding a URL-encoded
 *          (RFC 1738) version of "in" . Only A-Z a-z 0-9 . _ - are passed
 *          through unmodified.
 */
char *dav_disk_client_name_encode(apr_pool_t *pool, const char *in);

/** @brief Generates a delegation ID from the values exported by gridsite */
char* dav_disk_make_delegation_id(apr_pool_t* pool, apr_table_t* table);

/** @brief Returns the path of the delegated proxy, if existing and valid. NULL
 *         otherwise.
 */
char* dav_disk_get_proxy(request_rec* r, const char* proxy_dir,
        const char* user_dn);

#endif
