/**
 * @file   security.h
 * @brief  Security related functions.
 * @author Alejandro Álvarez Ayllón <aalvarez.cern.ch>
 */
#ifndef SECURITY_H_
#define	SECURITY_H_

#include <dmlite/c/dmlite.h>
#include <httpd.h>
#include <openssl/ssl.h>

#define DAV_SHARED_MAX_FQANS       32
#define DAV_SHARED_MAX_DELEGATION 512

/**
 * Interacts with mod_gridsite through environment variables and initializes
 * an instance of dav_shared_user_info.
 * @param pool    The pool used to allocate the needed data.
 * @param r       The request.
 * @param anon    The anonymous user, if any.
 * @param trusted The trusted DNs, if any.
 * @return        A pointer to an initialized struct credentials.
 *                NULL on error.
 */
dmlite_credentials *dav_shared_get_user_credentials(apr_pool_t *pool,
        request_rec *r, const char *anon_usr, const char *anon_grp,
        apr_array_header_t* trusted);

/**
 * Returns 1 if ssl is enabled in this request
 */
char is_ssl_used(request_rec *r);

#endif	/* SECURITY_H_ */
